@@ -21,11 +21,12 @@ def _init_obj_wrapper(fn):
     return new
 
 class StoredEntity(Entity):
-    def init(self, id=None, storageclient=None, queue=None):
+    def init(self, id=None, storageclient=None, queue=None, context = None):
         self.id = id
         self.s = storageclient
         self.obj = None
         self.queue = queue
+        self.context = context
         self.revert()
 
     @_init_obj_wrapper
@@ -187,6 +188,7 @@ class StoredEntity(Entity):
     def log(self, action, label, **kw):
         msg = {}
         msg.update(kw)
+        msg.update(self.context)
         msg['_id'] = self.id
         msg['_action'] = action
         msg['_label'] = label
