@@ -21,8 +21,8 @@ class FileMultiEntityFactory(object):
             return m.group()
         else:
             raise NotAValidStoreName()
-            
-    def __init__(self, storage_dir='data', queue=None, 
+
+    def __init__(self, storage_dir='data', queue=None,
                         prefix=SPECIAL_FILE_PREFIX, shorty_length=2):
         self.stores = {}
         self.queue = queue
@@ -30,9 +30,9 @@ class FileMultiEntityFactory(object):
         self.prefix = prefix
         self.shorty_length = shorty_length
         self.status = self.init_stores()
-    
+
     def __getitem__(self, index):
-        return self.stores[index]    
+        return self.stores[index]
     def __setitem__(self, index, obj):
         self.stores[index] = obj
     def keys(self):
@@ -65,10 +65,10 @@ class FileMultiEntityFactory(object):
                 if os.path.isdir(os.path.join(self.storage_dir, path)):
                     try:
                         store_path = os.path.join(self.storage_dir, path)
-                        store = FileEntityFactory(uri_base=None, 
-                                                  storage_dir=store_path, 
-                                                  queue=self.queue, 
-                                                  prefix=self.prefix, 
+                        store = FileEntityFactory(uri_base=None,
+                                                  storage_dir=store_path,
+                                                  queue=self.queue,
+                                                  prefix=self.prefix,
                                                   shorty_length=self.shorty_length)
                         status[path] = True
                         self.stores[path] = store
@@ -84,21 +84,23 @@ class FileMultiEntityFactory(object):
         else:
             raise StoreNotFoundException
 
-    def add_store(self, store_name, uri_base=None):
+    def add_store(self, store_name, uri_base=None, queue=None):
         store_name = self._sanitise(store_name)
         if store_name in self.stores:
             return self.stores[store_name]
         else:
+            if not queue:
+                queue = self.queue
             store_path = os.path.join(self.storage_dir, store_name)
             store = FileEntityFactory(uri_base=uri_base,
                                     storage_dir=store_path,
-                                    queue=self.queue,
+                                    queue=queue,
                                     prefix=self.prefix,
                                     shorty_length=self.shorty_length)
             self.status[store_name] = True
             self.stores[store_name] = store
             return store
-    
+
     def delete_store(self, store_name):
         store_name = self._sanitise(store_name)
         store_path = os.path.join(self.storage_dir, store_name)
@@ -106,7 +108,7 @@ class FileMultiEntityFactory(object):
             shutil.rmtree(store_path)
             del self.status[store_name]
             del self.stores[store_name]
-    
+
     def clone_store(self, copy_from_store, name_of_clone):
         store_name = self._sanitise(copy_from_store)
         name_of_clone = self._sanitise(name_of_clone)
@@ -121,7 +123,7 @@ class FileMultiEntityFactory(object):
                 return self.stores[name_of_clone]
             else:
                 raise StoreAlreadyExistsException(clone_path)
-        
+
     def rename_store(self, store_name, new_name):
         store_name = self._sanitise(store_name)
         new_name = self._sanitise(new_name)
@@ -134,21 +136,22 @@ class FileMultiEntityFactory(object):
 
     def get(self, uri):
         pass
-    
+
     def get_id(self, id, store):
         store = self._sanitise(store)
         if self.status.get(store, False) and store in self.stores:
             return self.stores[store].get_id(id)
 
 class FileEntityFactory(object):
-    def __init__(self, uri_base=URI_BASE, storage_dir=STORAGE_DIR, 
-                        queue=None, prefix=SPECIAL_FILE_PREFIX, shorty_length=2):
+    def __init__(self, uri_base=URI_BASE, storage_dir=STORAGE_DIR,
+                        queue=None, prefix=SPECIAL_FILE_PREFIX, shorty_length=2, context={}):
         """uri_base must end in an /, : or an #. If neither is present a / will be appended."""
         if uri_base and not(uri_base.endswith('/') or uri_base.endswith('#') or uri_base.endswith(':')):
             uri_base = "%s/" % uri_base
         factory_f = FileStorageFactory()
         self._q = queue
         self._s = factory_f.get_store(uri_base, storage_dir, prefix, shorty_length)
+        self._c = context
         # The store might have a different idea on what the prefix is:
         self.uri_base = self._s.uri_base
 
@@ -156,14 +159,14 @@ class FileEntityFactory(object):
     def get_id(self, id=None):
         uri = "%s%s" % (self.uri_base, id)
         s = StoredEntity(uri)
-        s.init(id, self._s, queue=self._q)
+        s.init(id, self._s, queue=self._q, context = self._c)
         return s
 
     def get(self, uri):
         if uri.startswith(self.uri_base):
             id = uri[len(self.uri_base):]
             s = StoredEntity(uri)
-            s.init(id, self._s, queue=self._q)
+            s.init(id, self._s, queue=self._q, context = self._c)
             return s
         else:
             raise Exception("TODO: uri not found")
@@ -175,3 +178,4 @@ class FileEntityFactory(object):
     def list_ids(self):
         """ EXPENSIVE - involves crawling the entire store pairtree directory"""
         return self._s.list_ids()
+
