@@ -56,6 +56,7 @@ class RDFobject(object):
         self.types = set([])
         self.g = None
         self.altered = False
+        self._cached = False
         #add defaults
         self.urihelper = URIHelper(self.namespaces)
         self.add_namespace(u'rdf', u'http://www.w3.org/1999/02/22-rdf-syntax-ns#')
@@ -207,9 +208,13 @@ class RDFobject(object):
         for s,p,o in g.triples((self.uri, None, None)):
             self.add_triple(p, o)
     
+    def __str__(self):
+        return self.to_string('xml')
+    
     def to_string(self, format="xml"):
-        self.altered = False
-        g = self.get_graph()
-        return g.serialize(format=format, encoding="utf-8")
+        if self.altered or self._cached == False:
+            self.altered = False
+            self._cached = self.get_graph()
+        return self._cached.serialize(format=format, encoding="utf-8")
         
 
