@@ -36,6 +36,8 @@ vid.put_stream('foobar', """Blah blah blah (v2)""")
 vid.put_stream('deleteme', """Blah blah blah""")
 vid.put_stream('deleteme', """Blah blah blah""")
 vid.put_stream('deleteme', """Blah blah blah""")
+vid.put_stream('deleteall', """Blah blah blah - all to go""")
+vid.put_stream('deleteall', """Blah blah blah - all to go""")
 vid.commit()
 # version delete
 
@@ -46,12 +48,14 @@ except VersionNotFoundException:
 
 # part delete
 
-vid.del_stream('deleteme')
+vid.del_stream('deleteall')
 
 print vid
 
 print "Parts: %s" % vid.list_parts()
 
+print "Deleteme Parts: %s" % vid.list_part_versions('deleteme')
+
 print "Versions of ROOT: %s" % vid.list_part_versions('ROOT')
 try:
     bar = f.clone_store('foo', 'barbar')
